var NAVTREEINDEX8 =
{
"group__API__SC__Hypervisor.html#a9aba37893ddb344de680aa901f686f2d":[5,47,3,1],
"group__API__SC__Hypervisor.html#ab44752ac4a1d34c397d8fe8b10e8611b":[5,47,2,6],
"group__API__SC__Hypervisor.html#ac676ac4892a469ad4674b560c2b92514":[5,47,2,10],
"group__API__SC__Hypervisor.html#ac6da5b817008cd1002fac2412ee1ccde":[5,47,3,2],
"group__API__SC__Hypervisor.html#ac71dc391218a17c435238f6bc42d2250":[5,47,2,0],
"group__API__SC__Hypervisor.html#acc8469538b2b9242e312fea26e13294c":[5,47,3,0],
"group__API__SC__Hypervisor.html#ae3a65239bb98f10756743787df0b9319":[5,47,2,1],
"group__API__SC__Hypervisor.html#aea7e98763fa2b2f5553cc73bf29705f7":[5,47,1,0],
"group__API__SC__Hypervisor.html#aec206144116e7360d2479a38a1c7f5f4":[5,47,1,3],
"group__API__SC__Hypervisor.html#afbd8b91f7650ffd4c21ecbf17771a3d0":[5,47,2,9],
"group__API__SC__Hypervisor.html#afdc378d28bfed82986912168bab0286b":[5,47,2,11],
"group__API__SC__Hypervisor.html#ga022e4bef8fa4b4e68f071cbaa69c7dd5":[5,47,43],
"group__API__SC__Hypervisor.html#ga035e61bdee7a98948b3c7e2e0b55ef21":[5,47,38],
"group__API__SC__Hypervisor.html#ga04164c5a91df51882e8bdd84fd1b1e3f":[5,47,10],
"group__API__SC__Hypervisor.html#ga0829a2976a7bdba7b3b5ef2124b863b2":[5,47,21],
"group__API__SC__Hypervisor.html#ga08b6cf1458859cdeebc6e53b5dd753cb":[5,47,45],
"group__API__SC__Hypervisor.html#ga0a4b27500994ca2c56047a7da18c6216":[5,47,50],
"group__API__SC__Hypervisor.html#ga3186197ffa198841262a976cb8544ec3":[5,47,28],
"group__API__SC__Hypervisor.html#ga32444b31927fbc49dc721ecbb66eae28":[5,47,47],
"group__API__SC__Hypervisor.html#ga39d8e769961cdc098d0b4cc56653f134":[5,47,31],
"group__API__SC__Hypervisor.html#ga44bf05d5f29cfacfdb178d78f68cab39":[5,47,37],
"group__API__SC__Hypervisor.html#ga44f9db8a2a97ebb45f813006c6fbd88f":[5,47,34],
"group__API__SC__Hypervisor.html#ga4808bbccd3d39478fae09a4feeaf7d65":[5,47,35],
"group__API__SC__Hypervisor.html#ga4a0ceff94ebf33871266bc73b630e9cb":[5,47,20],
"group__API__SC__Hypervisor.html#ga4ab22667e3bd2e963f7451552f716540":[5,47,11],
"group__API__SC__Hypervisor.html#ga562ea43bd369c85d762d49f71eebe928":[5,47,23],
"group__API__SC__Hypervisor.html#ga607deee22e3a1712c11df379be3aa38e":[5,47,53],
"group__API__SC__Hypervisor.html#ga6085b1585a13c94d48f185687c6a117c":[5,47,6],
"group__API__SC__Hypervisor.html#ga6adb0260d4c8a84612c2da05caebe02e":[5,47,16],
"group__API__SC__Hypervisor.html#ga6c0567dc4f96310053c5f953c024e443":[5,47,33],
"group__API__SC__Hypervisor.html#ga70c120158d02e550632de0ec5a207df4":[5,47,4],
"group__API__SC__Hypervisor.html#ga7ba4c0c3deca0dd4148ddd1f0b919792":[5,47,15],
"group__API__SC__Hypervisor.html#ga838703a5d26ea31f7415155ecbf1e490":[5,47,48],
"group__API__SC__Hypervisor.html#ga84e68fc3ee959e12c6b5d49b4db7a441":[5,47,36],
"group__API__SC__Hypervisor.html#ga894cc12da13c7e07534b2f31f8aef02c":[5,47,42],
"group__API__SC__Hypervisor.html#ga94eea335704bbfa52bc025ad4d49eb14":[5,47,9],
"group__API__SC__Hypervisor.html#ga96ec8fb00b7c1a93b7dd9e44deabbe77":[5,47,40],
"group__API__SC__Hypervisor.html#ga9734466cc2ae6b8fcd280a602ac1cf40":[5,47,25],
"group__API__SC__Hypervisor.html#ga9968686b96e842b384e2fd2495c8c7ab":[5,47,27],
"group__API__SC__Hypervisor.html#gaa2299b4916c0e8b3ffe5db762d37d092":[5,47,52],
"group__API__SC__Hypervisor.html#gaa768d65847bee6f26861217af9437ae2":[5,47,51],
"group__API__SC__Hypervisor.html#gaafac498199c6441e2d45c9b4eac8dfe4":[5,47,7],
"group__API__SC__Hypervisor.html#gab02cf89fff4e322e47bc96fb3b60b1ac":[5,47,44],
"group__API__SC__Hypervisor.html#gab4e7dd4e4841b9e3db584b903043c3ad":[5,47,41],
"group__API__SC__Hypervisor.html#gab5a609dbc1fe1703ff8b3d10410f7cc8":[5,47,22],
"group__API__SC__Hypervisor.html#gabcccdef713031ad99b58c302af45fe99":[5,47,32],
"group__API__SC__Hypervisor.html#gabf2475a79863da74418a12b2c5c37871":[5,47,13],
"group__API__SC__Hypervisor.html#gac3b55f616c270eb90c0103d6f062d384":[5,47,14],
"group__API__SC__Hypervisor.html#gac3e457f9b5741f587d241d62cc843f9e":[5,47,12],
"group__API__SC__Hypervisor.html#gad60118273ad73681cd4255cac8a06898":[5,47,18],
"group__API__SC__Hypervisor.html#gad8a9eb41efa7f8a918bc1d7dc8faa400":[5,47,46],
"group__API__SC__Hypervisor.html#gad9267ab01a8e5db5b357d8749f9e8e1a":[5,47,5],
"group__API__SC__Hypervisor.html#gaddb5b0b23b8a3511d85c0340a26da38b":[5,47,30],
"group__API__SC__Hypervisor.html#gae32be23caf7b19b9eab8f334ce8892d1":[5,47,54],
"group__API__SC__Hypervisor.html#gae5459ddc321818abc79d6af96b4af1ab":[5,47,17],
"group__API__SC__Hypervisor.html#gae897baba953584f77fda8c65ae7b25d1":[5,47,29],
"group__API__SC__Hypervisor.html#gaeb8f6b738e6d625ef57a2a687d5bf172":[5,47,26],
"group__API__SC__Hypervisor.html#gaf1f5a13894874d87363c32351f573c86":[5,47,8],
"group__API__SC__Hypervisor.html#gaf3788d6ae764b5864c5d4e74229166c6":[5,47,19],
"group__API__SC__Hypervisor.html#gaf3e884b4995e3dd608120e7fe0e48fae":[5,47,49],
"group__API__SC__Hypervisor.html#gafc5ea604211c8404014f99e4ba161341":[5,47,39],
"group__API__SC__Hypervisor.html#gaffba7dc9450156757654540cc6040bc3":[5,47,24],
"group__API__SC__Hypervisor.html#structsc__hypervisor__policy":[5,47,2],
"group__API__SC__Hypervisor.html#structsc__hypervisor__policy__task__pool":[5,47,1],
"group__API__SC__Hypervisor.html#structsc__hypervisor__resize__ack":[5,47,3],
"group__API__SC__Hypervisor.html#structtypes__of__workers":[5,47,0],
"group__API__SC__Hypervisor__LP.html":[5,48],
"group__API__SC__Hypervisor__LP.html#ga119a16db0b13d9d328b9644fbcfffb33":[5,48,11],
"group__API__SC__Hypervisor__LP.html#ga2cecd17791724a374b6fd2c8e1dff1f6":[5,48,12],
"group__API__SC__Hypervisor__LP.html#ga39b4f48eb3bade0001780c1a1e1c16a8":[5,48,8],
"group__API__SC__Hypervisor__LP.html#ga46fa52870d27246598b657b76d5cbd16":[5,48,9],
"group__API__SC__Hypervisor__LP.html#ga54777bfa24810b101784e5f7e45ff356":[5,48,4],
"group__API__SC__Hypervisor__LP.html#ga563843ede9e369216c3eeb2bd8e5237b":[5,48,6],
"group__API__SC__Hypervisor__LP.html#ga6074d44c0bedd93474d631546b90d602":[5,48,2],
"group__API__SC__Hypervisor__LP.html#ga7ef6d8b50b99d2e88b053791a1d5c588":[5,48,0],
"group__API__SC__Hypervisor__LP.html#ga8e6a76b7b67da9a200bd7755c5af0b0d":[5,48,3],
"group__API__SC__Hypervisor__LP.html#ga9983b17edc20a128abbcdc9d0e6c8a2f":[5,48,10],
"group__API__SC__Hypervisor__LP.html#gacc56bcf1548a4d5a082f9287672fbc13":[5,48,1],
"group__API__SC__Hypervisor__LP.html#gae07ce1123bc39d71ecc437201eac151e":[5,48,5],
"group__API__SC__Hypervisor__LP.html#gafd728af46e35624005c789cdcfdb8a9e":[5,48,7],
"group__API__SC__Hypervisor__usage.html":[5,49],
"group__API__SC__Hypervisor__usage.html#ga00c33eff0501ea8829cf2e7d4954b0fc":[5,49,23],
"group__API__SC__Hypervisor__usage.html#ga07b07d1fe5d41055f451fc92c60361e1":[5,49,1],
"group__API__SC__Hypervisor__usage.html#ga0a20609c85fa479c3fd5892399099416":[5,49,3],
"group__API__SC__Hypervisor__usage.html#ga0f47fee9448054de82ed44f1cb18fdde":[5,49,22],
"group__API__SC__Hypervisor__usage.html#ga1366fc9bb28170e9012dcad441696e52":[5,49,13],
"group__API__SC__Hypervisor__usage.html#ga15d008933c3c89906f613b3a24fff3cc":[5,49,0],
"group__API__SC__Hypervisor__usage.html#ga37713b9ab6d282f2b705240e630f1a4c":[5,49,10],
"group__API__SC__Hypervisor__usage.html#ga4c83e2984867267ea8c7da9fbaf23858":[5,49,2],
"group__API__SC__Hypervisor__usage.html#ga4dfbeda855bb8963c5332fdd796c0dcf":[5,49,18],
"group__API__SC__Hypervisor__usage.html#ga5f2b33a41a697759ee2a222e623f723c":[5,49,4],
"group__API__SC__Hypervisor__usage.html#ga5f34faa17f98f25bd874950ba1a15578":[5,49,15],
"group__API__SC__Hypervisor__usage.html#ga6398be50d801f0fc5ad73506e392d476":[5,49,17],
"group__API__SC__Hypervisor__usage.html#ga67d1dbb2ab01c8b712a9cd270fba4155":[5,49,5],
"group__API__SC__Hypervisor__usage.html#ga6fd674769c96a6b13b4e1b0d2e5a4f68":[5,49,20],
"group__API__SC__Hypervisor__usage.html#ga7b4cd59e4c0011400e7be4d4799e6b85":[5,49,24],
"group__API__SC__Hypervisor__usage.html#ga886533650f0dbbef618c7fdfa75f9f0e":[5,49,9],
"group__API__SC__Hypervisor__usage.html#ga960ae31e317c65bfa9cc6a4e539a0c84":[5,49,14],
"group__API__SC__Hypervisor__usage.html#gaa1e2878a06847489a4de2f33f62fa1af":[5,49,6],
"group__API__SC__Hypervisor__usage.html#gabbea0f33102b8457e07a1e8be3b158b0":[5,49,21],
"group__API__SC__Hypervisor__usage.html#gac89f5d5eba3f79151ef6b2a0e895f144":[5,49,19],
"group__API__SC__Hypervisor__usage.html#gaccfcc47b137572f79916bff5d12414d0":[5,49,11],
"group__API__SC__Hypervisor__usage.html#gadd6bc55408b1f618edb44da49300bb5c":[5,49,12],
"group__API__SC__Hypervisor__usage.html#gadf5585c656c7db3ee8f7b630b86e25e3":[5,49,16],
"group__API__SC__Hypervisor__usage.html#gae3ad958a1d841587df13c814ce966477":[5,49,7],
"group__API__SC__Hypervisor__usage.html#gae8ea0882790c8ea187bd366285230999":[5,49,8],
"group__API__SC__Hypervisor__usage.html#gaf192fa1a6a02127cab3482459235799a":[5,49,25],
"group__API__Scheduler__Toolbox.html":[5,26],
"group__API__Scheduler__Toolbox.html#ga058b39f24e2f3bf28c59a01ca319de8a":[5,26,8],
"group__API__Scheduler__Toolbox.html#ga0794188be8b76c5b73116d417713550f":[5,26,10],
"group__API__Scheduler__Toolbox.html#ga1daa7d8dddec1a06ab12e1ed14e1394c":[5,26,22],
"group__API__Scheduler__Toolbox.html#ga2a6fcd2c7cbe99454e2a51b12204127a":[5,26,21],
"group__API__Scheduler__Toolbox.html#ga63f59191335a287dc6202e509d074fe4":[5,26,13],
"group__API__Scheduler__Toolbox.html#ga6a1e78ec4a321e0799fbdaea8f36ba4a":[5,26,24],
"group__API__Scheduler__Toolbox.html#ga7aebe126291a3fe66dce072d370f14b9":[5,26,18],
"group__API__Scheduler__Toolbox.html#ga808043bcf6cf2d3a4ac4245671987227":[5,26,16],
"group__API__Scheduler__Toolbox.html#ga86bf03db6d762f481eeac63f5df7135f":[5,26,1],
"group__API__Scheduler__Toolbox.html#ga8a11b9d4f3165acd87b888b883daf14d":[5,26,14],
"group__API__Scheduler__Toolbox.html#ga8e55bfa706d002b95a0403d159991069":[5,26,20],
"group__API__Scheduler__Toolbox.html#gaa017c7f4241e139b81ce5e8dd960c15a":[5,26,23],
"group__API__Scheduler__Toolbox.html#gaa700cfc8317ec93c460c6c85f50b76d5":[5,26,3],
"group__API__Scheduler__Toolbox.html#gaab2f08162ac91a0c1e22786fa9b3a3b7":[5,26,2],
"group__API__Scheduler__Toolbox.html#gaabd9fd8e3bd8fee71425e5363740951d":[5,26,9],
"group__API__Scheduler__Toolbox.html#gaae4532236341a6bfe2b0759fe5cf065b":[5,26,0],
"group__API__Scheduler__Toolbox.html#gaaf3e157f80bacdafe5d73e85e26ce3ac":[5,26,17],
"group__API__Scheduler__Toolbox.html#gab02a32dfc3f8737068623986f2d57558":[5,26,11],
"group__API__Scheduler__Toolbox.html#gaba13f134ad4f4f7d7382e2525cd2a641":[5,26,15],
"group__API__Scheduler__Toolbox.html#gac63a190c974e2cff5b5dea335d34fa0a":[5,26,5],
"group__API__Scheduler__Toolbox.html#gad46bae443c6734bfedacab2a59f9f69d":[5,26,25],
"group__API__Scheduler__Toolbox.html#gadfd4156a5cc2aebdb1d1636b3f4cef34":[5,26,7],
"group__API__Scheduler__Toolbox.html#gae65cc165d0944487c5bf1d4527370280":[5,26,19],
"group__API__Scheduler__Toolbox.html#gae7099055e5b2334c0df61404db5d5022":[5,26,6],
"group__API__Scheduler__Toolbox.html#gae94f5e2adfa9b6b61cccadd80a74073d":[5,26,4],
"group__API__Scheduler__Toolbox.html#gaf11a472ce6d07052053fcf743a358662":[5,26,12],
"group__API__Scheduling__Contexts.html":[5,23],
"group__API__Scheduling__Contexts.html#ga02858b688df9fed9e593040de0d28357":[5,23,17],
"group__API__Scheduling__Contexts.html#ga0afc28558bb1ad29fbfe32d9c51522f8":[5,23,44],
"group__API__Scheduling__Contexts.html#ga0ef17ebcd4b58381d71423c93948ad42":[5,23,8],
"group__API__Scheduling__Contexts.html#ga0fe5c1b14fc254c8b2a737402870a149":[5,23,28],
"group__API__Scheduling__Contexts.html#ga101c3a13d4adc8d932c46324ae71b93a":[5,23,18],
"group__API__Scheduling__Contexts.html#ga11e94f2968626d9b46ccf021057ddd90":[5,23,23],
"group__API__Scheduling__Contexts.html#ga182b6196b075139f611cfd34b42b86e8":[5,23,24],
"group__API__Scheduling__Contexts.html#ga18af575377ee066528081b5aec754ea2":[5,23,26],
"group__API__Scheduling__Contexts.html#ga1945cfb563891ad94861e5a5f6b01495":[5,23,40],
"group__API__Scheduling__Contexts.html#ga1cfc7b78954e33f2738547cbf05e820e":[5,23,38],
"group__API__Scheduling__Contexts.html#ga1e642fe68ccbb8c5c661aab6c0d81283":[5,23,7],
"group__API__Scheduling__Contexts.html#ga1fbdfe8bacedde944e4c39e4bb168651":[5,23,13],
"group__API__Scheduling__Contexts.html#ga20077926e6cd8264bcbb831a394c381a":[5,23,32],
"group__API__Scheduling__Contexts.html#ga29e7f45270fa484dfa9ff9354dd5ae16":[5,23,35],
"group__API__Scheduling__Contexts.html#ga31a7eb9cb2f0e68a38ff3e613c7df34f":[5,23,16],
"group__API__Scheduling__Contexts.html#ga3bf2021fcc7d0be5a8d435a6ee1d9195":[5,23,36],
"group__API__Scheduling__Contexts.html#ga4e1aaf03ba327f47e5027c6fb7e5ed00":[5,23,20],
"group__API__Scheduling__Contexts.html#ga517b7cf4bfac60f2faf484584f19d9d3":[5,23,12],
"group__API__Scheduling__Contexts.html#ga5de2e1e6295cf1fa5723d1164d0a76e6":[5,23,42],
"group__API__Scheduling__Contexts.html#ga66d2d4d08df845a40b7d19f12bf791c0":[5,23,30],
"group__API__Scheduling__Contexts.html#ga66ed9279fc4eb746a0596c2f0be7daa2":[5,23,0],
"group__API__Scheduling__Contexts.html#ga6ae38faa632f496d81f0cf3b0cec5c77":[5,23,37],
"group__API__Scheduling__Contexts.html#ga6b8a02442fc4b18ae7f1c67a1a4add35":[5,23,39],
"group__API__Scheduling__Contexts.html#ga6e559a6889a89ec0b9a3b995a41f5f8f":[5,23,43],
"group__API__Scheduling__Contexts.html#ga7988c6119e176957987baac65f4fc62c":[5,23,9],
"group__API__Scheduling__Contexts.html#ga80c723b1a18a2104a28320430d8e8489":[5,23,3],
"group__API__Scheduling__Contexts.html#ga80f88b1017cfde58c18381a52ba0a122":[5,23,2],
"group__API__Scheduling__Contexts.html#ga9cdf99b6998b774eb53a8cc845f4e597":[5,23,1],
"group__API__Scheduling__Contexts.html#gaa06e10ab1edfe31d7da2f3359630e6f4":[5,23,29],
"group__API__Scheduling__Contexts.html#gaacd0aff652dc75ac37aa51c9c826e043":[5,23,33],
"group__API__Scheduling__Contexts.html#gaadbcaf9118792338aafe480da6fc6d94":[5,23,14],
"group__API__Scheduling__Contexts.html#gaaf3b5065cf505e6352070f2737a672a0":[5,23,15],
"group__API__Scheduling__Contexts.html#gab4f78ab0f73e1d29edd1824588b1a90c":[5,23,31],
"group__API__Scheduling__Contexts.html#gabd6c53517107a2b467bdbc8af21cee2c":[5,23,11],
"group__API__Scheduling__Contexts.html#gad6b7f96254526bb145e0df5ed0354a13":[5,23,19],
"group__API__Scheduling__Contexts.html#gad96f61bfad5945d03f32dfec0032f7ca":[5,23,4],
"group__API__Scheduling__Contexts.html#gae00f5710446d14161beefdad2e48833d":[5,23,27],
"group__API__Scheduling__Contexts.html#gae3437dfe9f125233c25bf58c9c6f87d7":[5,23,25],
"group__API__Scheduling__Contexts.html#gae3c8990276aaca0a3b44e3177ab3e0fb":[5,23,41],
"group__API__Scheduling__Contexts.html#gae6b235a9555a74e5cb4c89ca5117b419":[5,23,21],
"group__API__Scheduling__Contexts.html#gae71c0da99dd6af6193dd85710caf6c13":[5,23,5],
"group__API__Scheduling__Contexts.html#gaeb43bd3c56edb4bc4590eecc4eae76f0":[5,23,6],
"group__API__Scheduling__Contexts.html#gaf213c18d752d78286cff68a379ee7611":[5,23,10],
"group__API__Scheduling__Contexts.html#gaf9a95bcf18710622750367c0ba6acbb4":[5,23,34],
"group__API__Scheduling__Contexts.html#gafe295aec3c152fe1fc0dd74e17f82961":[5,23,22],
"group__API__Scheduling__Policy.html":[5,24],
"group__API__Scheduling__Policy.html#a0e378575c3d948a10e1025dd817bba67":[5,24,0,11],
"group__API__Scheduling__Policy.html#a126aefb44f8c9927e8c46007c29aa92d":[5,24,0,3],
"group__API__Scheduling__Policy.html#a1b1eade0d51badd5c9a2faaa49345b3e":[5,24,0,5],
"group__API__Scheduling__Policy.html#a3a9fac9431150cc6931f572969ba848e":[5,24,0,13],
"group__API__Scheduling__Policy.html#a44e18efefc5e383997cc5684e014bd82":[5,24,0,9],
"group__API__Scheduling__Policy.html#a70b01dc541e85aba64f46a4b69b68eed":[5,24,0,1],
"group__API__Scheduling__Policy.html#a73c1677d2c6af4d4aa44f6f92de8bcdd":[5,24,0,2],
"group__API__Scheduling__Policy.html#a741b2c45076cb62ca6f024b63432f232":[5,24,0,6],
"group__API__Scheduling__Policy.html#a81af53e5f8e59cb12d6d0b378c4b5268":[5,24,0,12],
"group__API__Scheduling__Policy.html#a84231c0bc118e91e49b0614c24b9de4a":[5,24,0,4],
"group__API__Scheduling__Policy.html#a9020a364719389cd19c31a657c938293":[5,24,0,10],
"group__API__Scheduling__Policy.html#ace93b3c465e39c7e2ca894406905dc2a":[5,24,0,0],
"group__API__Scheduling__Policy.html#ad720f2cd2155e8baa10f57792b68a5eb":[5,24,0,8],
"group__API__Scheduling__Policy.html#afd00e4e0a058e043c3d8edf916ace4f7":[5,24,0,7],
"group__API__Scheduling__Policy.html#ga1e159d56ffa2d7705bdfd1ceb93e0d64":[5,24,36],
"group__API__Scheduling__Policy.html#ga20525c5d674b32a9f64fbc9e23c5f55f":[5,24,23],
"group__API__Scheduling__Policy.html#ga21385d19bc75a7581e774bd455c70790":[5,24,28],
"group__API__Scheduling__Policy.html#ga24154b37920144de18bca59090429d6d":[5,24,18],
"group__API__Scheduling__Policy.html#ga2bb5cf545414379c1425a4b399fd75c2":[5,24,6],
"group__API__Scheduling__Policy.html#ga2c45db0c01e86497082c907b9cb0f4cc":[5,24,14],
"group__API__Scheduling__Policy.html#ga2dc83adec9e479e967a1d1c2ae40f916":[5,24,30],
"group__API__Scheduling__Policy.html#ga315482308105aa57ecc59e88f71823aa":[5,24,42],
"group__API__Scheduling__Policy.html#ga318f5a51b8f948940c754df6962be263":[5,24,35],
"group__API__Scheduling__Policy.html#ga3893905aa0eb62a541f268c6f37c491e":[5,24,44],
"group__API__Scheduling__Policy.html#ga39d52be64d37a80809f256c749fd37ca":[5,24,32],
"group__API__Scheduling__Policy.html#ga3aa31bfaf64f1281d2da89eac0dba84d":[5,24,5],
"group__API__Scheduling__Policy.html#ga3b98f64aa4214721c743883605f23dc3":[5,24,43],
"group__API__Scheduling__Policy.html#ga3bf8df94c9ea3f1370b53fff54e72888":[5,24,21],
"group__API__Scheduling__Policy.html#ga3dc8a0756db914507cd56782b3141dbb":[5,24,27],
"group__API__Scheduling__Policy.html#ga3e9efb4ca2cbc1c74757e0a9cb0f26c6":[5,24,37],
"group__API__Scheduling__Policy.html#ga40338a935c8428167c73e1d5b681b4e5":[5,24,15],
"group__API__Scheduling__Policy.html#ga42dd0f54842a3c78e9de6c84d72b4e0b":[5,24,20],
"group__API__Scheduling__Policy.html#ga4faf5df3280a5331bdddd3f878a3024d":[5,24,34],
"group__API__Scheduling__Policy.html#ga4fcf4007a35a9ddd44964311f6d7fda4":[5,24,2],
"group__API__Scheduling__Policy.html#ga53b042c111b450ebaa99e26388394ff4":[5,24,40],
"group__API__Scheduling__Policy.html#ga6c2233ec86c827981117306f63da7679":[5,24,11],
"group__API__Scheduling__Policy.html#ga6d34b96e4331258fc461788f2bf52bda":[5,24,22],
"group__API__Scheduling__Policy.html#ga6d8a3d42b5f2fee81785b3cf650fa6d2":[5,24,10],
"group__API__Scheduling__Policy.html#ga706830b50d163715c28d2fb19abd13bd":[5,24,16],
"group__API__Scheduling__Policy.html#ga7cfeacbeb8978b05754da35133eeba87":[5,24,26],
"group__API__Scheduling__Policy.html#ga7f9281edd60ddfaeded3c920a77edbf7":[5,24,46],
"group__API__Scheduling__Policy.html#ga8004f14208fd9b29f36440dc11ca765b":[5,24,25],
"group__API__Scheduling__Policy.html#ga87e2aacf5892951d5333a3421e90f278":[5,24,33],
"group__API__Scheduling__Policy.html#ga8e58ffd062043cf25b47c081b7f6ba88":[5,24,47],
"group__API__Scheduling__Policy.html#ga8eb834f05df5337dcd8c96f6a74cd1f1":[5,24,41],
"group__API__Scheduling__Policy.html#ga9424eb90a56d08f804d85be6557ddf66":[5,24,45],
"group__API__Scheduling__Policy.html#ga94edfd4a02666d8c1b8c506423586426":[5,24,19],
"group__API__Scheduling__Policy.html#ga98ec28ae7ac484959f48b7a79372c1af":[5,24,31],
"group__API__Scheduling__Policy.html#ga9e576ab0869a671c3cc482f385e1905b":[5,24,7],
"group__API__Scheduling__Policy.html#gaa01a5b65a4c387da5f7ca711c03d41c8":[5,24,9],
"group__API__Scheduling__Policy.html#gaa859b0ee59cfa2bde4d241f854c3bbea":[5,24,29],
"group__API__Scheduling__Policy.html#gab291c2011e9679a07d2eb632d58ac90c":[5,24,38],
"group__API__Scheduling__Policy.html#gab389801ed30db46c5620b3e0c0d6abd9":[5,24,4],
"group__API__Scheduling__Policy.html#gab8e4a2cd9f4fbad7b20b1086494d842d":[5,24,13],
"group__API__Scheduling__Policy.html#gac45e8699959436b91bcf9b0c56a805df":[5,24,1],
"group__API__Scheduling__Policy.html#gace525e755092440f63acbe5cc0b4d066":[5,24,12],
"group__API__Scheduling__Policy.html#gad95b1a3129b0b81a590b04289be72fc4":[5,24,39],
"group__API__Scheduling__Policy.html#gadf8e42d41b76117293db5651b0912c78":[5,24,8],
"group__API__Scheduling__Policy.html#gae0af4ea38016734474e4b76c97cca790":[5,24,24],
"group__API__Scheduling__Policy.html#gae0b8a9bb53822f3d92cb2d19c2520e5e":[5,24,17],
"group__API__Scheduling__Policy.html#gaeaa41beec214f474f9dce6689939e913":[5,24,3],
"group__API__Scheduling__Policy.html#structstarpu__sched__policy":[5,24,0],
"group__API__Sink.html":[5,43],
"group__API__Standard__Memory__Library.html":[5,44],
"group__API__Standard__Memory__Library.html#ga13b23ecc431501f8aebcb7b498acd92b":[5,44,19],
"group__API__Standard__Memory__Library.html#ga1456598a362e4ee275247bd1a1d4327b":[5,44,22],
"group__API__Standard__Memory__Library.html#ga18cb9a696ddb392c6874939c8cffd495":[5,44,20],
"group__API__Standard__Memory__Library.html#ga2abe959e39acfb75c7c0652706dfe84c":[5,44,0],
"group__API__Standard__Memory__Library.html#ga3506e4b5ab7a605e25968883ded27d64":[5,44,17]
};
